@@ -57,10 +57,10 @@ class RadioBrowser:
 
     """
 
-    base_url = pick_base_url()
     headers = {"User-Agent": "pyradios/{}".format(version)}
 
     def __init__(self, session=None, **kwargs):
+        self.base_url = pick_base_url()
         self._fmt = 'json'
         self.client = Request(headers=self.headers, session=session)
 
@@ -83,11 +83,11 @@ class RadioBrowser:
         """
 
         if code:
-            endpoint = "json/countrycodes/{code}".format(
+            endpoint = "json/countries/{code}".format(
                 code=code
             )
         else:
-            endpoint = "json/countrycodes/"
+            endpoint = "json/countries/"
         url = self.build_url(endpoint)
         return self.client.get(url)
 
@@ -280,7 +280,7 @@ class RadioBrowser:
         See details:
             https://de1.api.radio-browser.info/#List_of_radio_stations
         """
-        kwargs.update({"code": codec, "codec_exact": exact})
+        kwargs.update({"codec": codec, "codec_exact": exact})
         return self.search(**kwargs)
 
     def stations_by_country(self, country, exact=False, **kwargs):
